<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ko">
<context>
    <name>ReminderDialog</name>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="14"/>
        <source>Restart the computer to use the system and the applications properly</source>
        <translation>시스템 및 응용프로그램을 올바르게 사용하려면 컴퓨터를 다시 시작하십시오</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="15"/>
        <source>Make sure all data had been saved first</source>
        <translation>모든 데이터가 먼저 저장되었는지 확인하십시오</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="20"/>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="20"/>
        <source>Shut down</source>
        <translation>종료</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="23"/>
        <source>Reboot</source>
        <translation>재부팅</translation>
    </message>
</context>
</TS>